<?php

namespace App\Http\Controllers\Adminpanel;

use App\Http\Controllers\Controller;
use App\Models\Customer;
use App\Models\CustomerContactPersonDetail;
use Illuminate\Http\Request;
use DataTables;

class CustomersController extends Controller
{
    function __construct()
    {

        $this->middleware('permission:customers-list|customers-create|customers-edit|customers-delete', ['only' => ['list']]);
        $this->middleware('permission:customers-create', ['only' => ['index', 'store']]);
        $this->middleware('permission:customers-edit', ['only' => ['edit', 'update','activation']]);

    }

    public function index()
    {
        return view('adminpanel.customers.index');
    }

    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'customer_name' => 'required',
            'company_name' => 'required',
            'email' => 'required',
            'contact_number_1' => 'required',
            'address_line_1' => 'required'
        ]);

        $id = Customer::create($request->all())->id;

        \LogActivity::addToLog('New customer '.$request->customer_name.' added('.$id.').');

        if(!empty($request->contact_person_name[0]) && $request->contact_person_name[0] != null) {

            $contactPersonCount = count($request->contact_person_name) - 1;

            // dd($request->contact_person_title);

            for($i = 0; $i < $contactPersonCount; $i++) {
                try {
                $contactPersonDetail = new CustomerContactPersonDetail();
                $contactPersonDetail->title = $request->contact_person_title[$i];
                $contactPersonDetail->customer_id = $id;
                $contactPersonDetail->contact_person_name = $request->contact_person_name[$i];
                $contactPersonDetail->contact_person_designation = $request->contact_person_designation[$i];
                $contactPersonDetail->contact_person_email = $request->contact_person_email[$i];
                $contactPersonDetail->contact_person_contact_number = $request->contact_person_contact_number[$i];
                $contactPersonDetail->save();

                \LogActivity::addToLog('New contact person '.$request->contact_person_name[$i].' added to customer ('.$id.').');

                } catch (\Exception $e) {
                    // dd($e);
                    return redirect()->route('customers-list')->with('error', 'Contact person details save is not success.');
                }
            }

        }

        return redirect()->route('customers-list')->with('success', 'Record created successfully.');
    }

    public function list(Request $request)
    {
        if ($request->ajax()) {
            $data = Customer::where('is_delete', 0)->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-customers/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->addColumn('activation', function($row){
                    if ( $row->status == "Y" )
                        $status ='fa fa-check';
                    else
                        $status ='fa fa-remove';

                        $encryptedId = encrypt($row->id);

                    $btn = '<a href="change-status-customers/'.$encryptedId.'/'.$row->cEnable.'"><i class="'.$status.'"></i></a>';

                    return $btn;
                })
                ->addColumn('delete', 'adminpanel.customers.actionsBlock')
                ->rawColumns(['edit', 'activation','delete'])
                ->make(true);
        }

        return view('adminpanel.customers.list');
    }

    public function edit($id)
    {
        $customerId = decrypt($id);
        $data = Customer::find($customerId);
        $contactPersonDetails = CustomerContactPersonDetail::where('customer_id', $customerId)->get();

        return view('adminpanel.customers.edit', ['data' => $data, 'contactPersonDetails' => $contactPersonDetails]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'customer_name' => 'required',
            'company_name' => 'required',
            'email' => 'required',
            'contact_number_1' => 'required',
            'address_line_1' => 'required'
        ]);

        $data =  Customer::find($request->id);
        $data->title = $request->title;
        $data->customer_name = $request->customer_name;
        $data->company_name = $request->company_name;
        $data->email = $request->email;
        $data->contact_number_1 = $request->contact_number_1;
        $data->contact_number_2 = $request->contact_number_2;
        $data->address_line_1 = $request->address_line_1;
        $data->address_line_2 = $request->address_line_2;
        $data->address_line_3 = $request->address_line_3;
        $data->status = $request->status;
        $data->save();

        $id = $data->id;

        if(!empty($request->contact_person_name[0]) && $request->contact_person_name[0] != null) {

            $contactPersonCount = count($request->contact_person_name) - 1;

            // dd($request->contact_person_title);

            for($i = 0; $i < $contactPersonCount; $i++) {
                try {
                $contactPersonDetail = new CustomerContactPersonDetail();
                $contactPersonDetail->title = $request->contact_person_title[$i];
                $contactPersonDetail->customer_id = $id;
                $contactPersonDetail->contact_person_name = $request->contact_person_name[$i];
                $contactPersonDetail->contact_person_designation = $request->contact_person_designation[$i];
                $contactPersonDetail->contact_person_email = $request->contact_person_email[$i];
                $contactPersonDetail->contact_person_contact_number = $request->contact_person_contact_number[$i];
                $contactPersonDetail->save();

                \LogActivity::addToLog('New contact person '.$request->contact_person_name[$i].' added to customer ('.$id.').');

                } catch (\Exception $e) {
                    // dd($e);
                    return redirect()->route('customers-list')->with('error', 'Contact person details save is not success.');
                }
            }

        }

        \LogActivity::addToLog('Customer record '.$data->customer_name.' updated('.$id.').');

        return redirect()->route('customers-list')
            ->with('success', 'Record updated successfully.');
    }

    public function activation(Request $request)
    {

        $id = decrypt($request->id);

        $data =  Customer::find($id);

        if ( $data->status == "Y" ) {

            $data->status = 'N';
            $data->save();
            $id = $data->id;

            \LogActivity::addToLog('Customer record '.$data->name.' deactivated('.$id.').');

            return redirect()->route('customers-list')
            ->with('success', 'Record deactivate successfully.');

        } else {

            $data->status = "Y";
            $data->save();
            $id = $data->id;

            \LogActivity::addToLog('Customer record '.$data->name.' activated('.$id.').');

            return redirect()->route('customers-list')
            ->with('success', 'Record activate successfully.');
        }

    }

    public function delete(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $customerId = decrypt($request->id);
        $data =  Customer::find($customerId);
        $data->is_delete = 1;
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Customer record '.$data->name.' deleted('.$id.').');

        return redirect()->route('customers-list')
            ->with('success', 'Record deleted successfully.');
    }

    public function deleteContactPerson(Request $request)
    {
        $data =  CustomerContactPersonDetail::find($request->id);
        $data->delete();

        \LogActivity::addToLog('Customer Contact person record deleted.');

        return redirect()->back()
            ->with('success', 'Record deleted successfully.');
    }
}
