<?php

namespace App\Http\Controllers\Adminpanel;

use App\Http\Controllers\Controller;
use App\Models\CompanyBankDetail;
use App\Models\CompanyContactPersonDetail;
use App\Models\CompanyDetail;
use App\Models\Customer;
use App\Models\CustomerContactPersonDetail;
use App\Models\Invoice;
use App\Models\PaymentTerm;
use App\Models\Project;
use App\Models\Quotation;
use App\Models\QuotationPaymentTerm;
use App\Models\QuotationVersionRecord;
use App\Models\ValidityPeriod;
// use Barryvdh\DomPDF\Facade as PDF;
use Illuminate\Http\Request;
use DataTables;
use Illuminate\Support\Facades\Storage;
use PDF;

class InvoiceController extends Controller
{
    function __construct()
    {

     $this->middleware('permission:invoice-list|invoice-create|invoice-edit|invoice-delete', ['only' => ['list']]);
     $this->middleware('permission:invoice-create', ['only' => ['index', 'store']]);
     $this->middleware('permission:invoice-edit', ['only' => ['edit', 'update','activation']]);

    }

    public function index()
    {
        $quotations = Quotation::select('quotations.id','quotations.quotation_id','projects.project_name')
                                ->distinct()
                                ->join('projects', 'projects.id', '=', 'quotations.project_id')
                                ->join('quotation_payment_terms', 'quotation_payment_terms.quotation_id', '=', 'quotations.id')
                                ->where('quotation_payment_terms.payment_status', 'P')
                                ->where('quotations.status', 'Y')
                                ->where('quotations.is_delete', 0)
                                ->get();
        $salespersons = CompanyContactPersonDetail::get();
        $validityPeriods = ValidityPeriod::where('status', 'Y')->where('is_delete', 0)->get();
        $customers = Customer::where('status', 'Y')->where('is_delete', 0)->get();
        $projects = Project::where('status', 'Y')->where('is_delete', 0)->get();
        $customercontactpersons = CustomerContactPersonDetail::get();

        return view('adminpanel.invoices.index', compact('quotations','salespersons','customercontactpersons','validityPeriods','customers','projects'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'payment_term_id' => 'required',
            'company_name' => 'required',
            'cust_contact_person' => 'required',
            'sales_person' => 'required',
            'unit_price' => 'required',
            'invoice_date' => 'required',
            'invoice_total_value' => 'required'
        ]);

        $lastInvoiceId = Invoice::orderBy('id', 'DESC')->first();

        if(!empty($lastInvoiceId))
        {
            $lastInvoiceSerial = $lastInvoiceId->invoice_id;
            $arrSerial = explode('-', $lastInvoiceSerial);
            if($arrSerial)
            {
                $lastSerial = $arrSerial[0];
            }
        } else {
            $lastSerial = 0;
        }

        $currentMonthNumber = \Carbon\Carbon::now()->format('m');

        $newSerialNo = str_pad($lastSerial + 1, 4, '0', STR_PAD_LEFT);
        $newInvoiceId = $newSerialNo.'-TG-Q'.$currentMonthNumber;

        if(!empty($request->quotationid)) {
            $quotationId = $request->quotationid;
        } else {
            $quotationId = $request->quotation_id;
        }

        $invoiceAmount = str_replace(',', '', $request->invoice_total_value);

        $newInvoice = new Invoice();
        $newInvoice->invoice_id = $newInvoiceId;
        $newInvoice->invoice_date = $request->invoice_date;
        $newInvoice->quotation_id = $quotationId;
        $newInvoice->payment_term_id = $request->payment_term_id;
        $newInvoice->cust_contact_person_id = $request->cust_contact_person;
        $newInvoice->sales_person_id = $request->sales_person;
        $newInvoice->po_number = $request->po_number;
        $newInvoice->fob_point = $request->fob_point;
        $newInvoice->remarks = $request->remarks;
        $newInvoice->terms = $request->terms;
        $newInvoice->project_id = $request->project_id;
        $newInvoice->total_invoice_value = $invoiceAmount;
        $newInvoice->save();

        $id = $newInvoice->id;

        $updateQuotePayTerms = QuotationPaymentTerm::where('quotation_id', $quotationId)->where('payment_term_id', $request->payment_term_id)->first();
        $updateQuotePayTerms->payment_status = "C";
        $updateQuotePayTerms->save();

        \LogActivity::addToLog('New invoice record '.$newInvoiceId.' added('.$id.').');


        return redirect()->route('invoice-list')->with('success', 'Record created successfully.');

        // return view('adminpanel.quotations.print_quotation', compact('quotationdetails','paymentterms','companydetails'));
    }

    public function list(Request $request)
    {
        if ($request->ajax()) {
            $data = Invoice::with('projects','quotations')->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('project_name', function ($row) {
                    $projectName = $row->projects->project_name;
                    return $projectName;
                })
                ->addColumn('contact_person', function ($row) {
                    $contactPersonName = $row->customercontactpersons->contact_person_name;
                    return $contactPersonName;
                })
                ->addColumn('payment_term', function ($row) {
                    $paymentTerm = $row->paymentterms->payment_term;
                    return $paymentTerm;
                })
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-invoice/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->addColumn('print', function ($row) {
                    $print_url = url('/print-invoice/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $print_url . '"><i class="fa fa-print"></i></a>';
                    return $btn;
                })
                ->addColumn('quotationid', function ($row) {
                    $quotationsid = $row->quotations->quotation_id;
                    return $quotationsid;
                })
                ->addColumn('generate_invoice', function ($row) {

                    $invoicepdf = '';
                    if(!empty($row->invoice_pdf)) {
                        $invoiceurl = "storage/app/$row->invoice_pdf";
                        $invoicepdf .= '<a href="' . $invoiceurl . '" target="_blank"><i style="color: red" class="fa fa-file-pdf-o"></i></a> ';
                    } else {
                        $invoicepdf = '';
                    }


                    return $invoicepdf; // Return all PDF icons concatenated together
                })
                ->rawColumns(['project_name','contact_person','payment_term','quotationid','edit','print','generate_invoice'])
                ->make(true);
        }

        return view('adminpanel.invoices.list');
    }

    public function edit($id)
    {
        $invoiceId = decrypt($id);
        $data = Invoice::with('projects','quotations')->find($invoiceId);
        // dd($data);
        $paymentTerms = QuotationPaymentTerm::select('payment_terms.id', 'payment_terms.payment_term')
                                            ->join('payment_terms', 'payment_terms.id', '=', 'quotation_payment_terms.payment_term_id')
                                            ->where('quotation_id', $data->quotation_id)
                                            ->get();
        $customerContactPersons = CustomerContactPersonDetail::where('customer_id', $data->quotations->customer_id)->get();
        $companyContactPersons = CompanyContactPersonDetail::get();


        return view('adminpanel.invoices.edit', ['data' => $data, 'paymentTerms' => $paymentTerms, 'customerContactPersons' => $customerContactPersons,
                'companyContactPersons' => $companyContactPersons]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'payment_term_id' => 'required',
            'company_name' => 'required',
            'cust_contact_person' => 'required',
            'sales_person' => 'required',
            'unit_price' => 'required',
            'invoice_date' => 'required',
            'invoice_total_value' => 'required'
        ]);

        $invoicedetails = Invoice::where('id', $request->invoice_id)->first();

        if($invoicedetails->payment_term_id != $request->payment_term_id)
        {
            $quotationpaymentterm = QuotationPaymentTerm::where('quotation_id', $invoicedetails->quotation_id)
                                                        ->where('payment_term_id', $invoicedetails->payment_term_id)
                                                        ->first();
            $quotationpaymentterm->payment_status =  "P";
            $quotationpaymentterm->save();
        }

        $invoiceAmount = str_replace(',', '', $request->invoice_total_value);

        $data = Invoice::find($request->invoice_id);
        $data->invoice_date = $request->invoice_date;
        $data->payment_term_id = $request->payment_term_id;
        $data->cust_contact_person_id = $request->cust_contact_person;
        $data->sales_person_id = $request->sales_person;
        $data->po_number = $request->po_number;
        $data->fob_point = $request->fob_point;
        $data->remarks = $request->remarks;
        $data->terms = $request->terms;
        $data->project_id = $request->project_id;
        $data->total_invoice_value = $invoiceAmount;
        $data->save();

        $id = $data->id;

        $updateQuotePayTerms = QuotationPaymentTerm::where('quotation_id', $invoicedetails->quotation_id)->where('payment_term_id', $request->payment_term_id)->first();
        $updateQuotePayTerms->payment_status = "C";
        $updateQuotePayTerms->save();

        \LogActivity::addToLog('Invoice record '.$invoicedetails->invoice_id.' updated('.$id.').');

        return redirect()->back()
            ->with('success', 'Record updated successfully.');
    }

    public function print($id)
    {
        $invoiceId = decrypt($id);
        $invoice = Invoice::with('customercontactpersons','projects','quotations','salespersons')->where('id', $invoiceId)->first();
        $bankdetails = CompanyBankDetail::first();
        $companydetails = CompanyDetail::first();

        // return redirect()->route('quotation-list')
        //     ->with('success', 'Record created successfully.');

        $pdf = PDF::loadView('adminpanel.invoices.print_invoice', ['invoice' => $invoice, 'companydetails' => $companydetails, 'bankdetails' => $bankdetails]);

        // Define a unique file name
        $fileName = 'invoice_pt_'.$invoice->payment_term_id.'_'.$invoice->invoice_id.'_'.$invoice->projects->project_name.'.pdf';

        // Save the PDF to the storage folder
        Storage::put('public/invoices/' . $fileName, $pdf->output());

        // Save the file path to the database
        $invoice->invoice_pdf = 'public/invoices/' . $fileName;
        $invoice->save();

        return response()->download(storage_path('app/public/invoices/' . $fileName), $fileName, [
            'Content-Type' => 'application/pdf'
        ]);

            // Redirect to a view with the download URL
        // $downloadUrl = asset('storage/invoices/' . $fileName); // Get the public URL
        // return view('adminpanel.invoices.download', compact('downloadUrl'));
    }

    public function getProjectDetails(Request $request)
    {

        $companydetails = Quotation::select('customers.company_name','projects.project_name','quotations.total_cost','quotations.project_id')
                                    ->join('customers', 'customers.id', '=', 'quotations.customer_id')
                                    ->join('projects', 'projects.id', '=', 'quotations.project_id')
                                    ->where('quotations.id', $request->quotation_id)
                                    ->get();

        return response()->json($companydetails);
    }

    public function getCustomerContactDetails(Request $request)
    {

        $customercontactdetails = Quotation::select('customers_contact_person_details.id','customers_contact_person_details.contact_person_name')
                                    ->join('customers_contact_person_details', 'customers_contact_person_details.customer_id', '=', 'quotations.customer_id')
                                    ->where('quotations.id', $request->quotation_id)
                                    ->get();

        return response()->json($customercontactdetails);
    }
}
