<?php

namespace App\Http\Controllers\Adminpanel;

use App\Http\Controllers\Controller;
use App\Models\CompanyContactPersonDetail;
use App\Models\CompanyDetail;
use App\Models\Customer;
use App\Models\CustomerContactPersonDetail;
use App\Models\EmailSetting;
use App\Models\MaintenanceType;
use App\Models\NewMaintenance;
use App\Models\PaymentTerm;
use App\Models\Project;
use App\Models\Quotation;
use App\Models\QuotationPaymentTerm;
use App\Models\QuotationVersionRecord;
use App\Models\ValidityPeriod;
use Illuminate\Http\Request;
use DataTables;
use Illuminate\Support\Facades\Storage;
use PDF;

class MaintenanceManagementController extends Controller
{
    function __construct()
    {

     $this->middleware('permission:maintenance-list|maintenance-create|maintenance-edit|maintenance-delete|maintenance-delete', ['only' => ['list']]);
     $this->middleware('permission:maintenance-create', ['only' => ['index', 'store']]);
     $this->middleware('permission:maintenance-edit', ['only' => ['edit', 'update','activation']]);
     $this->middleware('permission:maintenance-cancel', ['only' => ['cancel']]);
    }

    public function index()
    {
        $customers = Customer::where('status', 'Y')->where('is_delete', 0)->get();
        $maintenanceTypes = MaintenanceType::where('status', 'Y')->where('is_delete', 0)->get();
        $projects = Project::where('status', 'Y')->where('is_delete', 0)->get();
        $contactPersons = CompanyContactPersonDetail::get();

        return view('adminpanel.maintenance.index', compact('customers','maintenanceTypes','projects','contactPersons'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'customer_id' => 'required',
            'maintenance_type_id' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
        ]);

        if($request->project_type == 1) {
            $request->validate([
                'project_name' => 'required',
            ]);
            $newproject = new Project();
            $newproject->project_name = $request->project_name;
            $newproject->customer_id = $request->customer_id;
            $newproject->save();

            $projectId = $newproject->id;
        } else {
            $request->validate([
                'project_id' => 'required',
            ]);
            $projectId = $request->project_id;
        }

        // dd($newQuotationId);

        $newMaintenance = new NewMaintenance();
        $newMaintenance->customer_id = $request->customer_id;
        $newMaintenance->project_id = $projectId;
        $newMaintenance->maintenance_type_id = $request->maintenance_type_id;
        $newMaintenance->start_date = $request->start_date;
        $newMaintenance->end_date = $request->end_date;
        $newMaintenance->renewal_status = 'O';
        $newMaintenance->save();

        $id = $newMaintenance->id;

        \LogActivity::addToLog('New maintenance record added('.$id.').');


        return redirect()->route('quotation-list')->with('success', 'Record created successfully.');
    }

    public function list(Request $request)
    {
        if ($request->ajax()) {
            $data = NewMaintenance::with('customers','projects','maintenanceTypes')->where('is_delete', 0)->Where('status','Y')->where('renewal_status', 'O')->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('customer_name', function ($row) {
                    $customerName = $row->customers->customer_name;
                    return $customerName;
                })
                ->addColumn('project_name', function ($row) {
                    $projectName = $row->projects->project_name;
                    return $projectName;
                })
                ->addColumn('maintenance_type', function ($row) {
                    $projectName = $row->maintenanceTypes->type;
                    return $projectName;
                })
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-maintenance/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->addColumn('update_status', function ($row) {
                    $edit_url = url('/update-maintenance-status/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-share"></i></a>';
                    return $btn;
                })
                ->addColumn('cancel', function($row){

                    $encryptedId = encrypt($row->id);
                    $btn = '<a href="cancel-maintenance/'.$encryptedId.'"><i class="fa fa-ban"></i></a>';

                    return $btn;
                })
                ->rawColumns(['edit','customer_name','project_name','maintenance_type','cancel','update_status'])
                ->make(true);
        }

        return view('adminpanel.maintenance.list');
    }

    public function edit($id)
    {
        $maintenanceId = decrypt($id);
        $data = NewMaintenance::with('projects')->find($maintenanceId);
        $maintenanceTypes = MaintenanceType::where('status', 'Y')->where('is_delete', 0)->get();
        $customers = Customer::where('status', 'Y')->where('is_delete', 0)->get();

        return view('adminpanel.maintenance.edit', ['data' => $data, 'maintenanceTypes' => $maintenanceTypes,'customers' => $customers]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'customer_id' => 'required',
            'maintenance_type_id' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
        ]);

        $maintenance = NewMaintenance::with('projects')->find($request->id);
        $maintenance->customer_id = $request->customer_id;
        $maintenance->maintenance_type_id = $request->maintenance_type_id;
        $maintenance->start_date = $request->start_date;
        $maintenance->end_date = $request->end_date;
        $maintenance->save();

        \LogActivity::addToLog('Maintenance record '.$maintenance->projects->project_name.' updated('.$request->id.').');

        return redirect()->back()
            ->with('success', 'Record updated successfully.');
    }

    public function cancel(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $id = decrypt($request->id);

        $data =  NewMaintenance::find($id);

        $data->renewal_status = 'C';
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Maintenance record '.$data->quotation_id.' cancel('.$id.').');

        return redirect()->route('maintenance-list')
        ->with('success', 'Record cancel successfully.');

    }

    public function cancelList(Request $request)
    {
        if ($request->ajax()) {
            $data = NewMaintenance::with('customers','projects','maintenanceTypes')->where('status', 'Y')->where('renewal_status', 'C')->where('is_delete', 0)->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('customer_name', function ($row) {
                    $customerName = $row->customers->customer_name;
                    return $customerName;
                })
                ->addColumn('project_name', function ($row) {
                    $projectName = $row->projects->project_name;
                    return $projectName;
                })
                ->addColumn('maintenance_type', function ($row) {
                    $projectName = $row->maintenanceTypes->type;
                    return $projectName;
                })
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-maintenance/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->addColumn('cancel', function($row){

                    $encryptedId = encrypt($row->id);
                    $btn = '<a href="cancel-maintenance/'.$encryptedId.'"><i class="fa fa-ban"></i></a>';

                    return $btn;
                })
                ->addColumn('view', function ($row) {
                    $edit_url = url('/view-maintenance/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-eye"></i></a>';
                    return $btn;
                })
                ->rawColumns(['edit','customer_name','project_name','maintenance_type','cancel','view'])
                ->make(true);
        }

        return view('adminpanel.maintenance.cancel_list');
    }

    public function view($id)
    {
        $maintenanceId = decrypt($id);
        $data = NewMaintenance::with('customers','projects','maintenanceTypes')->find($maintenanceId);
        $maintenanceTypes = MaintenanceType::where('status', 'Y')->where('is_delete', 0)->get();
        $customers = Customer::where('status', 'Y')->where('is_delete', 0)->get();

        return view('adminpanel.maintenance.view', ['data' => $data, 'maintenanceTypes' => $maintenanceTypes,'customers' => $customers]);
    }

    public function updateStatus($id)
    {
        $maintenanceId = decrypt($id);
        $data = NewMaintenance::with('projects')->find($maintenanceId);
        $maintenanceTypes = MaintenanceType::where('status', 'Y')->where('is_delete', 0)->get();
        $customers = Customer::where('status', 'Y')->where('is_delete', 0)->get();

        return view('adminpanel.maintenance.update_status', ['data' => $data, 'maintenanceTypes' => $maintenanceTypes,'customers' => $customers]);
    }

    public function saveUpdatedStatus(Request $request)
    {
        $request->validate([
            'renewal_status' => 'required',
        ]);

        $maintenance = NewMaintenance::with('projects')->find($request->id);
        $maintenance->renewal_status = $request->renewal_status;
        $maintenance->renewal_status_update_date = date('Y-m-d');
        $maintenance->save();

        \LogActivity::addToLog('Maintenance record '.$maintenance->projects->project_name.' updated('.$request->id.') status to('.$request->renewal_status.').');

        return redirect()->back()
            ->with('success', 'Record updated successfully.');
    }

    public function renewalCompletedList(Request $request)
    {
        if ($request->ajax()) {
            $data = NewMaintenance::with('customers','projects','maintenanceTypes')->where('status', 'Y')->where('renewal_status', 'D')->where('is_delete', 0)->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('customer_name', function ($row) {
                    $customerName = $row->customers->customer_name;
                    return $customerName;
                })
                ->addColumn('project_name', function ($row) {
                    $projectName = $row->projects->project_name;
                    return $projectName;
                })
                ->addColumn('maintenance_type', function ($row) {
                    $projectName = $row->maintenanceTypes->type;
                    return $projectName;
                })
                ->addColumn('view', function ($row) {
                    $edit_url = url('/view-maintenance/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-eye"></i></a>';
                    return $btn;
                })
                ->rawColumns(['edit','customer_name','project_name','maintenance_type','cancel','view'])
                ->make(true);
        }

        return view('adminpanel.maintenance.renewal_completed_list');
    }

}
