<?php

namespace App\Http\Controllers\Adminpanel\Masterdata;

use App\Http\Controllers\Controller;
use App\Models\CompanyBankDetail;
use App\Models\CompanyContactPersonDetail;
use App\Models\CompanyDetail;
use Illuminate\Http\Request;
use DataTables;

class CompanyDetailController extends Controller
{
    function __construct()
    {

     $this->middleware('permission:company-details|company-details-edit', ['only' => ['list']]);
     $this->middleware('permission:company-details-edit', ['only' => ['edit', 'update','activation']]);

    }

    public function list(Request $request)
    {
        if ($request->ajax()) {
            $data = CompanyDetail::get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-company-details/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->rawColumns(['edit'])
                ->make(true);
        }

        return view('adminpanel.masterdata.company_details.list');
    }

    public function edit($id)
    {
        $companyDetailId = decrypt($id);
        $data = CompanyDetail::find($companyDetailId);
        $contactPersons = CompanyContactPersonDetail::get();
        $bankDetails = CompanyBankDetail::first();
        // dd($data->logo);
        return view('adminpanel.masterdata.company_details.edit', ['data' => $data, 'contactPersons' => $contactPersons, 'encryptedId' => $id, 'bankDetails' => $bankDetails]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'company_name' => 'required',
            'company_tel' => 'required',
            'address' => 'required',
            'company_email' => 'required',
            'website_url' => 'required',
            'account_name' => 'required',
            'bank_name' => 'required',
            'branch_name' => 'required',
            'account_number' => 'required'
        ]);

        $data =  CompanyDetail::find($request->id);
        $data->company_name = $request->company_name;
        $data->company_tel = $request->company_tel;
        $data->address = $request->address;
        $data->company_email = $request->company_email;
        $data->website_url = $request->website_url;

        if ($request->hasFile('logo')) {

            $companyLogo = $request->file('logo')->getClientOriginalName();

            $path = $request->file('logo')->store('public/company_details');

            $data->logo = $path;
        }

        $data->save();

        $bankdetails = CompanyBankDetail::first();
        $bankdetails->account_name = $request->account_name;
        $bankdetails->bank_name = $request->bank_name;
        $bankdetails->branch_name = $request->branch_name;
        $bankdetails->account_number = $request->account_number;
        $bankdetails->bank_code = $request->bank_code;
        $bankdetails->branch_code = $request->branch_code;
        $bankdetails->swift_code = $request->swift_code;
        $bankdetails->save();

        if(!empty($request->contact_person_name[0]) && $request->contact_person_name[0] != null) {

            $contactPersonCount = count($request->contact_person_name) - 1;

            for($i = 0; $i < $contactPersonCount; $i++) {

                try {
                    $contactPerson = new  CompanyContactPersonDetail();
                    $contactPerson->contact_person_name = $request->contact_person_name[$i];
                    $contactPerson->contact_person_designation = $request->contact_person_designation[$i];
                    $contactPerson->contact_person_contact_no = $request->contact_person_contact_no[$i];
                    $contactPerson->contact_person_email = $request->contact_person_email[$i];
                    $contactPerson->save();

                 } catch (\Exception $e) {
                    // dd($e);
                }
            }
        }


        $id = $data->id;

        \LogActivity::addToLog('Company details record updated('.$id.').');

        return redirect()->route('company-details')
            ->with('success', 'Record updated successfully.');
    }

    public function delete(Request $request)
    {

        $data =  CompanyContactPersonDetail::find($request->id);
        $data->delete();

        \LogActivity::addToLog('Contact person record deleted.');

        return redirect()->back()
            ->with('success', 'Record deleted successfully.');
    }
}
