<?php

namespace App\Http\Controllers\Adminpanel\Masterdata;

use App\Http\Controllers\Controller;
use App\Models\CompanyContactPersonDetail;
use App\Models\EmailSetting;
use App\Models\EmailSettingType;
use App\Models\EmailsSendingContact;
use App\Models\MaintenanceType;
use Illuminate\Http\Request;
use DataTables;
use Illuminate\Support\Facades\DB;

class EmailSettingsController extends Controller
{
    function __construct()
    {

     $this->middleware('permission:email-settings-list|email-settings-create|email-settings-edit|email-settings-delete', ['only' => ['list']]);
     $this->middleware('permission:email-settings-create', ['only' => ['index', 'store']]);
     $this->middleware('permission:email-settings-edit', ['only' => ['edit', 'update','activation']]);

    }

    public function index()
    {
        $emailSettingTypes = EmailSettingType::where('status','Y')->where('is_delete',0)->get();
        $contactPersons = CompanyContactPersonDetail::get();

        return view('adminpanel.masterdata.email_settings.index', compact('emailSettingTypes','contactPersons'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'setting_type' => 'required',
            'contact_person_id' => 'required',
        ]);

        $emailsCount = count($request->contact_person_id);

        for($i=0; $i<$emailsCount; $i++)
        {
            $newEmailsSendingContact = new EmailsSendingContact();
            $newEmailsSendingContact->setting_type = $request->setting_type;
            $newEmailsSendingContact->contact_person_id = $request->contact_person_id[$i];
            $newEmailsSendingContact->save();
        }

        \LogActivity::addToLog('Email settings added.');

        return redirect()->route('email-settings-list')
            ->with('success', 'Record created successfully.');
    }

    public function list(Request $request)
    {
        if ($request->ajax()) {

            // $data = EmailsSendingContact::with('moduleTypes')
            //                             ->select('id', 'setting_type', 'contact_person_id', 'created_at', 'updated_at')
            //                             ->distinct('type')
            //                             ->get();
            $data = EmailSettingType::join('emails_sending_contacts', 'emails_sending_contacts.setting_type', '=', 'email_setting_types.id')
            ->select('email_setting_types.id', 'email_setting_types.type', DB::raw('MIN(emails_sending_contacts.id) as sendingContactId'))
            ->groupBy('email_setting_types.id', 'email_setting_types.type')
            ->get();

            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-email-settings/' . encrypt($row->sendingContactId) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->rawColumns(['module','edit'])
                ->make(true);
        }

        return view('adminpanel.masterdata.email_settings.list');
    }

    public function edit($id)
    {
        $emailSettingId = decrypt($id);
        $emailSettingTypes = EmailSettingType::where('status','Y')->where('is_delete',0)->get();
        $data = EmailsSendingContact::with('moduleTypes')->find($emailSettingId);
        $contactPersons = CompanyContactPersonDetail::get();
        $selectedContactPersons = EmailsSendingContact::where('setting_type', $data->setting_type)->get();

        return view('adminpanel.masterdata.email_settings.edit', ['data' => $data, 'contactPersons' => $contactPersons,
        'selectedContactPersons' => $selectedContactPersons, 'emailSettingTypes' => $emailSettingTypes]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'setting_type' => 'required',
            'contact_person_id' => 'required',
        ]);

        $emailsCount = count($request->contact_person_id);

        if($emailsCount>0)
        {
            $deleteContactPersons = EmailsSendingContact::where('setting_type', $request->setting_type)->delete();
            for($i=0; $i<$emailsCount; $i++)
            {
                $newEmailsSendingContact = new EmailsSendingContact();
                $newEmailsSendingContact->setting_type = $request->setting_type;
                $newEmailsSendingContact->contact_person_id = $request->contact_person_id[$i];
                $newEmailsSendingContact->save();
            }

        }

        \LogActivity::addToLog('Email settings records updated');

        return redirect()->route('email-settings-list')
            ->with('success', 'Records updated successfully.');
    }

    public function checkExistingTypes(Request $request)
    {

        $existRecord = DB::table('emails_sending_contacts')
                        ->where('setting_type', $request->setting_type)
                        ->exists();

        if ($existRecord) {
            // year exists
            return 1;
        } else {
              // does not year exists
            return 0;
        }
    }
}
