<?php

namespace App\Http\Controllers\Adminpanel\Masterdata;

use App\Http\Controllers\Controller;
use App\Models\MaintenanceType;
use Illuminate\Http\Request;
use DataTables;

class MaintenanceTypeController extends Controller
{
    function __construct()
    {

     $this->middleware('permission:maintenance-type-list|maintenance-type-create|maintenance-type-edit|maintenance-type-delete', ['only' => ['list']]);
     $this->middleware('permission:maintenance-type-create', ['only' => ['index', 'store']]);
     $this->middleware('permission:maintenance-type-edit', ['only' => ['edit', 'update','activation']]);

    }

    public function index()
    {
        return view('adminpanel.masterdata.maintenance_type.index');
    }

    public function store(Request $request)
    {
        $request->validate([
            'type' => 'required'
        ]);

        $id = MaintenanceType::create($request->all())->id;

        \LogActivity::addToLog('New maintenance type '.$request->type.' added('.$id.').');

        return redirect()->route('maintenance-type-list')
            ->with('success', 'Record created successfully.');
    }

    public function list(Request $request)
    {
        if ($request->ajax()) {
            $data = MaintenanceType::where('is_delete', 0)->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-maintenance-type/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->addColumn('activation', function($row){
                    if ( $row->status == "Y" )
                        $status ='fa fa-check';
                    else
                        $status ='fa fa-remove';

                        $encryptedId = encrypt($row->id);

                    $btn = '<a href="change-status-maintenance-type/'.$encryptedId.'/'.$row->cEnable.'"><i class="'.$status.'"></i></a>';

                    return $btn;
                })
                ->addColumn('delete', 'adminpanel.masterdata.maintenance_type.actionsBlock')
                ->rawColumns(['edit', 'activation','delete'])
                ->make(true);
        }

        return view('adminpanel.masterdata.maintenance_type.list');
    }

    public function edit($id)
    {
        $maintenanceTypeId = decrypt($id);
        $data = MaintenanceType::find($maintenanceTypeId);
        return view('adminpanel.masterdata.maintenance_type.edit', ['data' => $data]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'type' => 'required'
        ]);

        $data =  MaintenanceType::find($request->id);
        $data->type = $request->type;
        $data->status = $request->status;
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Maintenance type record '.$data->type.' updated('.$id.').');

        return redirect()->route('maintenance-type-list')
            ->with('success', 'Record updated successfully.');
    }

    public function activation(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $id = decrypt($request->id);

        $data =  MaintenanceType::find($id);

        if ( $data->status == "Y" ) {

            $data->status = 'N';
            $data->save();
            $id = $data->id;

            \LogActivity::addToLog('Maintenance type record '.$data->type.' deactivated('.$id.').');

            return redirect()->route('maintenance-type-list')
            ->with('success', 'Record deactivate successfully.');

        } else {

            $data->status = "Y";
            $data->save();
            $id = $data->id;

            \LogActivity::addToLog('Maintenance type record '.$data->type.' activated('.$id.').');

            return redirect()->route('maintenance-type-list')
            ->with('success', 'Record activate successfully.');
        }

    }

    public function delete(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $maintenanceTypeId = decrypt($request->id);
        $data =  MaintenanceType::find($maintenanceTypeId);
        $data->is_delete = 1;
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Maintenance type record '.$data->type.' deleted('.$id.').');

        return redirect()->route('maintenance-type-list')
            ->with('success', 'Record deleted successfully.');
    }
}
