<?php

namespace App\Http\Controllers\Adminpanel\Masterdata;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\PaymentTerm;
use DataTables;

class PaymentTermController extends Controller
{
    function __construct()
    {

     $this->middleware('permission:payment-terms-list|payment-terms-create|payment-terms-edit|payment-terms-delete', ['only' => ['list']]);
     $this->middleware('permission:payment-terms-create', ['only' => ['index', 'store']]);
     $this->middleware('permission:payment-terms-edit', ['only' => ['edit', 'update','activation']]);

    }

    public function index()
    {
        return view('adminpanel.masterdata.payment_terms.index');
    }

    public function store(Request $request)
    {
        $request->validate([
            'payment_term' => 'required',
            'percentage' => 'required'
        ]);

        $id = PaymentTerm::create($request->all())->id;

        \LogActivity::addToLog('New payment term '.$request->payment_term.' added('.$id.').');

        return redirect()->route('payment-terms-list')
            ->with('success', 'Record created successfully.');
    }

    public function list(Request $request)
    {
        if ($request->ajax()) {
            $data = PaymentTerm::where('is_delete', 0)->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-payment-terms/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->addColumn('activation', function($row){
                    if ( $row->status == "Y" )
                        $status ='fa fa-check';
                    else
                        $status ='fa fa-remove';

                        $encryptedId = encrypt($row->id);

                    $btn = '<a href="change-status-payment-terms/'.$encryptedId.'/'.$row->cEnable.'"><i class="'.$status.'"></i></a>';

                    return $btn;
                })
                ->addColumn('delete', 'adminpanel.masterdata.payment_terms.actionsBlock')
                ->rawColumns(['edit', 'activation','delete'])
                ->make(true);
        }

        return view('adminpanel.masterdata.payment_terms.list');
    }

    public function edit($id)
    {
        $paymentTermId = decrypt($id);
        $data = PaymentTerm::find($paymentTermId);
        return view('adminpanel.masterdata.payment_terms.edit', ['data' => $data]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'payment_term' => 'required',
            'percentage' => 'required'
        ]);

        $data =  PaymentTerm::find($request->id);
        $data->payment_term = $request->payment_term;
        $data->percentage = $request->percentage;
        $data->status = $request->status;
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Payment term record '.$data->payment_term.' updated('.$id.').');

        return redirect()->route('payment-terms-list')
            ->with('success', 'Record updated successfully.');
    }

    public function activation(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $id = decrypt($request->id);

        $data =  PaymentTerm::find($id);

        if ( $data->status == "Y" ) {

            $data->status = 'N';
            $data->save();
            $id = $data->id;

            \LogActivity::addToLog('Payment terms record '.$data->payment_term.' deactivated('.$id.').');

            return redirect()->route('payment-terms-list')
            ->with('success', 'Record deactivate successfully.');

        } else {

            $data->status = "Y";
            $data->save();
            $id = $data->id;

            \LogActivity::addToLog('Payment terms record '.$data->payment_term.' activated('.$id.').');

            return redirect()->route('payment-terms-list')
            ->with('success', 'Record activate successfully.');
        }

    }

    public function delete(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $paymentTermId = decrypt($request->id);
        $data =  PaymentTerm::find($paymentTermId);
        $data->is_delete = 1;
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Payment terms record '.$data->payment_term.' deleted('.$id.').');

        return redirect()->route('payment-terms-list')
            ->with('success', 'Record deleted successfully.');
    }
}
