<?php

namespace App\Http\Controllers\Adminpanel\Masterdata;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\PaymentTerm;
use App\Models\ValidityPeriod;
use DataTables;

class ValidityPeriodController extends Controller
{
    function __construct()
    {

     $this->middleware('permission:validity-periods-list|validity-periods-create|validity-periods-edit|validity-periods-delete', ['only' => ['list']]);
     $this->middleware('permission:validity-periods-create', ['only' => ['index', 'store']]);
     $this->middleware('permission:validity-periods-edit', ['only' => ['edit', 'update','activation']]);

    }

    public function index()
    {
        return view('adminpanel.masterdata.validity_periods.index');
    }

    public function store(Request $request)
    {
        $request->validate([
            'validity_period' => 'required'
        ]);

        $id = ValidityPeriod::create($request->all())->id;

        \LogActivity::addToLog('New validity period '.$request->validity_period.' added('.$id.').');

        return redirect()->route('validity-periods-list')
            ->with('success', 'Record created successfully.');
    }

    public function list(Request $request)
    {
        if ($request->ajax()) {
            $data = ValidityPeriod::where('is_delete', 0)->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-validity-periods/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->addColumn('activation', function($row){
                    if ( $row->status == "Y" )
                        $status ='fa fa-check';
                    else
                        $status ='fa fa-remove';

                        $encryptedId = encrypt($row->id);

                    $btn = '<a href="change-status-validity-periods/'.$encryptedId.'/'.$row->cEnable.'"><i class="'.$status.'"></i></a>';

                    return $btn;
                })
                ->addColumn('delete', 'adminpanel.masterdata.validity_periods.actionsBlock')
                ->rawColumns(['edit', 'activation','delete'])
                ->make(true);
        }

        return view('adminpanel.masterdata.validity_periods.list');
    }

    public function edit($id)
    {
        $validityPeriodId = decrypt($id);
        $data = ValidityPeriod::find($validityPeriodId);
        return view('adminpanel.masterdata.validity_periods.edit', ['data' => $data]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'validity_period' => 'required'
        ]);

        $data =  ValidityPeriod::find($request->id);
        $data->validity_period = $request->validity_period;
        $data->status = $request->status;
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Validity period record '.$data->validity_period.' updated('.$id.').');

        return redirect()->route('validity-periods-list')
            ->with('success', 'Record updated successfully.');
    }

    public function activation(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $id = decrypt($request->id);

        $data =  ValidityPeriod::find($id);

        if ( $data->status == "Y" ) {

            $data->status = 'N';
            $data->save();
            $id = $data->id;

            \LogActivity::addToLog('Validity period record '.$data->validity_period.' deactivated('.$id.').');

            return redirect()->route('validity-periods-list')
            ->with('success', 'Record deactivate successfully.');

        } else {

            $data->status = "Y";
            $data->save();
            $id = $data->id;

            \LogActivity::addToLog('Validity period record '.$data->validity_period.' activated('.$id.').');

            return redirect()->route('validity-periods-list')
            ->with('success', 'Record activate successfully.');
        }

    }

    public function delete(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $validityPeriodId = decrypt($request->id);
        $data =  ValidityPeriod::find($validityPeriodId);
        $data->is_delete = 1;
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Validity period record '.$data->validity_period.' deleted('.$id.').');

        return redirect()->route('validity-periods-list')
            ->with('success', 'Record deleted successfully.');
    }
}
