<?php

namespace App\Http\Controllers\Adminpanel;

use App\Http\Controllers\Controller;
use App\Models\CompanyContactPersonDetail;
use App\Models\CompanyDetail;
use App\Models\Customer;
use App\Models\CustomerContactPersonDetail;
use App\Models\PaymentTerm;
use App\Models\Project;
use App\Models\Quotation;
use App\Models\QuotationPaymentTerm;
use App\Models\QuotationVersionRecord;
use App\Models\ValidityPeriod;
// use Barryvdh\DomPDF\Facade as PDF;
use Illuminate\Http\Request;
use DataTables;
use Illuminate\Support\Facades\Storage;
use PDF;

class QuotationsController extends Controller
{
    function __construct()
    {

     $this->middleware('permission:quotation-list|quotation-create|quotation-edit|quotation-delete', ['only' => ['list']]);
     $this->middleware('permission:quotation-create', ['only' => ['index', 'store']]);
     $this->middleware('permission:quotation-edit', ['only' => ['edit', 'update','activation']]);

    }

    public function index()
    {
        $paymentTerms = PaymentTerm::where('status', 'Y')->where('is_delete', 0)->get();
        $validityPeriods = ValidityPeriod::where('status', 'Y')->where('is_delete', 0)->get();
        $companyContactPersons = CompanyContactPersonDetail::get();
        $customers = Customer::where('status', 'Y')->where('is_delete', 0)->get();
        $projects = Project::where('status', 'Y')->where('is_delete', 0)->get();

        return view('adminpanel.quotations.index', compact('paymentTerms','validityPeriods','companyContactPersons','customers','projects'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'quotation_date' => 'required',
            'quotation_type' => 'required',
            'customer_id' => 'required',
            'customer_contact_person_id' => 'required',
            'project_type' => 'required',
            'quotation_title' => 'required',
            'quotation_description' => 'required',
            'time_est_category' => 'required',
            'est_time_period' => 'required',
            'scope_description' => 'required',
            'project_cost' => 'required',
            'total_cost' => 'required',
            'payment_terms' => 'required',
            'validity_period_id' => 'required',
            'contact_person_id' => 'required'
        ]);

        if($request->project_type == 1) {
            $newproject = new Project();
            $newproject->project_name = $request->project_name;
            $newproject->customer_id = $request->customer_id;
            $newproject->save();

            $projectId = $newproject->id;
        } else {
            $projectId = $request->project_id;
        }

        $lastQuoteId = Quotation::orderBy('id', 'DESC')->first();

        if(!empty($lastQuoteId))
        {
            $lastQuoteSerial = $lastQuoteId->quotation_id;
            $arrSerial = explode('-', $lastQuoteSerial);
            if($arrSerial)
            {
                $lastSerial = $arrSerial[0];
            }
        } else {
            $lastSerial = 0;
        }

        $currentMonthNumber = \Carbon\Carbon::now()->format('m');

        $newSerialNo = str_pad($lastSerial + 1, 4, '0', STR_PAD_LEFT);
        $newQuotationId = $newSerialNo.'-TG-QT'.$currentMonthNumber;

        // dd($newQuotationId);

        $newquotation = new Quotation();
        $newquotation->quotation_id = $newQuotationId;
        $newquotation->quotation_date = $request->quotation_date;
        $newquotation->quotation_type = $request->quotation_type;
        $newquotation->customer_id = $request->customer_id;
        $newquotation->customer_contact_person_id = $request->customer_contact_person_id;
        $newquotation->project_status = $request->project_type;
        $newquotation->project_id = $projectId;
        $newquotation->quotation_title = $request->quotation_title;
        $newquotation->quotation_description = $request->quotation_description;
        if($request->time_est_category != '') {
            $selectedestcates = $request->input('time_est_category');
            $timeestcatarr = implode(',', $selectedestcates);
            $newquotation->time_est_category = $timeestcatarr;
        }
        $newquotation->est_time_period = $request->est_time_period;
        $newquotation->scope_description = $request->scope_description;
        $newquotation->project_cost = $request->project_cost;
        $newquotation->discount = $request->discount;
        $newquotation->total_cost = $request->total_cost;
        if($request->payment_terms != '') {
            $selectedpaymentterms = $request->input('payment_terms');
            $paymenttermsarr = implode(',', $selectedpaymentterms);
            $newquotation->payment_terms = $paymenttermsarr;
        }
        $newquotation->validity_period_id = $request->validity_period_id;
        $newquotation->contact_person_id = $request->contact_person_id;
        // dd($newquotation);
        $newquotation->save();

        $id = $newquotation->id;

        $paymentterms = $request->input('payment_terms');

        $paymenttermcount = count($paymentterms);


        for($i=0; $i<$paymenttermcount; $i++)
        {
            $quotationpaymentterm = new QuotationPaymentTerm();
            $quotationpaymentterm->quotation_id = $id;
            $quotationpaymentterm->payment_term_id = $paymentterms[$i];
            $quotationpaymentterm->payment_status = "P";
            $quotationpaymentterm->save();
        }

        \LogActivity::addToLog('New quotation record '.$newQuotationId.' added('.$id.').');


        return redirect()->route('quotation-list')->with('success', 'Record created successfully.');

        // return view('adminpanel.quotations.print_quotation', compact('quotationdetails','paymentterms','companydetails'));
    }

    public function list(Request $request)
    {
        if ($request->ajax()) {
            $data = Quotation::with('customers','projects')->whereNot('status', 'C')->where('is_delete', 0)->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('customer_name', function ($row) {
                    $customerName = $row->customers->customer_name;
                    return $customerName;
                })
                ->addColumn('project_name', function ($row) {
                    $projectName = $row->projects->project_name;
                    return $projectName;
                })
                ->addColumn('quotation_version', function ($row) {
                    $quotationversions = QuotationVersionRecord::where('quotation_id', $row->id)->get();
                    $quotationpdf = '';
                    $quotationpdf1 = '';

                    $div = '<div style="display: flex; gap: 15px;">';
                    $divclose = '</div>';
                    foreach ($quotationversions as $version) {
                        $pdfurl = "storage/app/$version->pdf";
                        $quotationpdf1 .= '<a href="' . $pdfurl . '" target="_blank" style="display: flex; flex-direction: column;"><i style="color: red" class="fa fa-file-pdf-o"></i>'.$version->version.'</a>';
                        $quotationpdf = $div.$quotationpdf1.$divclose;
                    }

                    return $quotationpdf; // Return all PDF icons concatenated together
                })
                ->addColumn('print', function ($row) {
                    $quotationversions = QuotationVersionRecord::where('quotation_id', $row->id)->get();

                    if($quotationversions->isNotEmpty()) {
                        return '';
                    }elseif($quotationversions->isEmpty()) {
                        $print_url = url('/print-quotation/' . encrypt($row->id) . '');
                        $btn = '<a href="' . $print_url . '"><i class="fa fa-print"></i></a>';
                        return $btn;
                    }

                })
                ->addColumn('invoice_generate', function ($row) {
                    $generate_invoice_url = url('/generate-invoice/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $generate_invoice_url . '"><i class="fa fa-file-text-o"></i></a>';
                    return $btn;
                })
                ->addColumn('edit', function ($row) {
                    $edit_url = url('/edit-quotation/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $edit_url . '"><i class="fa fa-edit"></i></a>';
                    return $btn;
                })
                ->addColumn('cancel', function($row){

                    $encryptedId = encrypt($row->id);
                    $btn = '<a href="quotation-cancel/'.$encryptedId.'"><i class="fa fa-ban"></i></a>';

                    return $btn;
                })
                ->rawColumns(['edit','customer_name','project_name','print','quotation_version','invoice_generate','cancel'])
                ->make(true);
        }

        return view('adminpanel.quotations.list');
    }

    public function edit($id)
    {
        $quotationId = decrypt($id);
        $data = Quotation::with('projects')->find($quotationId);
        $paymentTerms = PaymentTerm::where('status', 'Y')->where('is_delete', 0)->get();
        $validityPeriods = ValidityPeriod::where('status', 'Y')->where('is_delete', 0)->get();
        $companyContactPersons = CompanyContactPersonDetail::get();
        $customers = Customer::where('status', 'Y')->where('is_delete', 0)->get();
        $projects = Project::where('status', 'Y')->where('is_delete', 0)->get();
        $customerContactPersons = CustomerContactPersonDetail::where('customer_id', $data->customer_id)->get();

        return view('adminpanel.quotations.edit', ['data' => $data, 'paymentTerms' => $paymentTerms, 'validityPeriods' => $validityPeriods,
                'companyContactPersons' => $companyContactPersons, 'customers' => $customers, 'projects' => $projects, 'customerContactPersons' => $customerContactPersons]);
    }

    public function update(Request $request)
    {
        $request->validate([
            'quotation_date' => 'required',
            'quotation_type' => 'required',
            'customer_contact_person_id' => 'required',
            'quotation_description' => 'required',
            'quotation_title' => 'required',
            'time_est_category' => 'required',
            'est_time_period' => 'required',
            'scope_description' => 'required',
            'project_cost' => 'required',
            'total_cost' => 'required',
            'payment_terms' => 'required',
            'validity_period_id' => 'required',
            'contact_person_id' => 'required'
        ]);

        $quotation = Quotation::find($request->id);
        $quotation->quotation_date = $request->quotation_date;
        $quotation->quotation_type = $request->quotation_type;
        $quotation->customer_contact_person_id = $request->customer_contact_person_id;
        $quotation->quotation_title = $request->quotation_title;
        $quotation->quotation_description = $request->quotation_description;
        if($request->time_est_category != '') {
            $selectedestcates = $request->input('time_est_category');
            $timeestcatarr = implode(',', $selectedestcates);
            $quotation->time_est_category = $timeestcatarr;
        }
        $quotation->est_time_period = $request->est_time_period;
        $quotation->scope_description = $request->scope_description;
        $quotation->project_cost = $request->project_cost;
        $quotation->discount = $request->discount;
        $quotation->total_cost = $request->total_cost;
        if($request->payment_terms != '') {
            $selectedpaymentterms = $request->input('payment_terms');
            $paymenttermsarr = implode(',', $selectedpaymentterms);
            $quotation->payment_terms = $paymenttermsarr;
        }
        $quotation->validity_period_id = $request->validity_period_id;
        $quotation->contact_person_id = $request->contact_person_id;
        // dd($quotation);
        $quotation->save();

        QuotationPaymentTerm::where('quotation_id', $request->id)->delete();

        $paymentterms = $request->input('payment_terms');

        $paymenttermcount = count($paymentterms);

        for($i=0; $i<$paymenttermcount; $i++)
        {
            $quotationpaymentterm = new QuotationPaymentTerm();
            $quotationpaymentterm->quotation_id = $request->id;
            $quotationpaymentterm->payment_term_id = $paymentterms[$i];
            $quotationpaymentterm->payment_status = "P";
            $quotationpaymentterm->save();
        }

        \LogActivity::addToLog('Quotation record '.$quotation->quotation_id.' updated('.$request->id.').');

        return redirect()->back()
            ->with('success', 'Record updated successfully.');
    }

    public function cancel(Request $request)
    {
        $request->validate([
            // 'status' => 'required'
        ]);

        $id = decrypt($request->id);

        $data =  Quotation::find($id);

        $data->status = 'C';
        $data->save();
        $id = $data->id;

        \LogActivity::addToLog('Quotation record '.$data->quotation_id.' cancel('.$id.').');

        return redirect()->route('quotation-list')
        ->with('success', 'Record cancel successfully.');

    }

    public function getProjects(Request $request)
    {
        $projects = Project::where('customer_id', $request->customer_id)->where('status', 'Y')->where('is_delete', 0)->get();
        return response()->json($projects);
    }

    public function getCustomerContactPersons(Request $request)
    {
        $customerContactPersons = CustomerContactPersonDetail::where('customer_id', $request->customer_id)->get();

        return response()->json($customerContactPersons);
    }

    public function print($id)
    {
        $quotationId = decrypt($id);
        $quotationdetails = Quotation::with('customercontactpersons','customers','validityperiods','contactpersondetails')->where('id', $quotationId)->first();
        $paymentterms = QuotationPaymentTerm::with('paymentterms')->where('quotation_id', $quotationId)->get();
        $companydetails = CompanyDetail::first();
        $printedquotationversions = QuotationVersionRecord::where('quotation_id', $quotationId)->orderBy('id', 'DESC')->first();

        if($printedquotationversions) {
        $versionArr = str_split($printedquotationversions->version);
        $versionNum = $versionArr[1];
        $latestversion = $versionNum + 1;
        }  else {
            $latestversion = 1;
        }


        // return redirect()->route('quotation-list')
        //     ->with('success', 'Record created successfully.');

        $pdf = PDF::loadView('adminpanel.quotations.print_quotation', ['quotationdetails' => $quotationdetails, 'paymentterms' => $paymentterms, 'companydetails' => $companydetails]);

        // Define a unique file name
        $fileName = 'quotation_' . $quotationdetails->quotation_id . '_V'.$latestversion.'.pdf';

        // Save the PDF to the storage folder
        Storage::put('public/quotations/' . $fileName, $pdf->output());

        // Save the file path to the database
        $newquotationversionrecord = new QuotationVersionRecord();
        $newquotationversionrecord->quotation_id = $quotationId;
        $newquotationversionrecord->version = 'V'.$latestversion;
        $newquotationversionrecord->pdf = 'public/quotations/' . $fileName;
        $newquotationversionrecord->save();

        // return response()->download(storage_path('app/public/quotations/' . $fileName), $fileName, [
        //     'Content-Type' => 'application/pdf'
        // ]);

            // Redirect to a view with the download URL
        $downloadUrl = asset('storage/quotations/' . $fileName); // Get the public URL
        return view('adminpanel.quotations.download', compact('downloadUrl'));
    }

    public function generateInvoice($id)
    {
        $quotationId = decrypt($id);
        $quotationDetails = Quotation::with('projects')->find($quotationId);
        $quotations = Quotation::with('projects')->where('status', 'Y')->where('is_delete', 0)->get();
        $paymentterms = PaymentTerm::where('status', 'Y')->where('is_delete', 0)->get();

        $customercontactpersons = CustomerContactPersonDetail::where('customer_id', $quotationDetails->customer_id)->get();
        $customerdetails = Customer::find($quotationDetails->customer_id);

        $salespersons = CompanyContactPersonDetail::get();

        return view('adminpanel.invoices.index', compact('quotationDetails','quotations', 'quotationId','paymentterms','customercontactpersons','customerdetails','salespersons'));
    }

    public function getPaymentTerms(Request $request)
    {

        $paymentterms = QuotationPaymentTerm::select('payment_terms.id','payment_terms.payment_term','payment_terms.percentage')
                                            ->join('payment_terms', 'payment_terms.id', '=', 'quotation_payment_terms.payment_term_id')
                                            ->where('quotation_payment_terms.quotation_id', $request->quotation_id)
                                            ->where('quotation_payment_terms.payment_status', 'P')
                                            ->get();

        return response()->json($paymentterms);
    }

    public function getPaymentTermPercentage(Request $request)
    {

        $paymentPercentage = PaymentTerm::select('id','percentage')
                                            ->where('id', $request->payment_term_id)
                                            ->first();

        return response()->json($paymentPercentage);
    }

    public function cancelList(Request $request)
    {
        if ($request->ajax()) {
            $data = Quotation::with('customers','projects')->where('status', 'C')->where('is_delete', 0)->get();
            // die(var_dump($data));
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('customer_name', function ($row) {
                    $customerName = $row->customers->customer_name;
                    return $customerName;
                })
                ->addColumn('project_name', function ($row) {
                    $projectName = $row->projects->project_name;
                    return $projectName;
                })
                 ->addColumn('view', function ($row) {
                    $view_url = url('/view-quotation/' . encrypt($row->id) . '');
                    $btn = '<a href="' . $view_url . '"><i class="fa fa-eye"></i></a>';
                    return $btn;
                })
                ->rawColumns(['customer_name','project_name','view'])
                ->make(true);
        }

        return view('adminpanel.quotations.cancel_list');
    }

    public function view($id)
    {
        $quotationId = decrypt($id);
        $data = Quotation::with('customers','customercontactpersons','projects','validityperiods','contactpersondetails')->find($quotationId);
        $paymentTerms = PaymentTerm::where('status', 'Y')->where('is_delete', 0)->get();

        return view('adminpanel.quotations.view', ['data' => $data, 'paymentTerms' => $paymentTerms]);
    }

}
