<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('quotations', function (Blueprint $table) {
            $table->id();
            $table->string('quotation_id');
            $table->date('quotation_date');
            $table->char('quotation_type',2);
            $table->unsignedBigInteger('customer_id');
            $table->foreign('customer_id')->references('id')->on('customers')->onDelete('cascade');
            $table->unsignedBigInteger('customer_contact_person_id');
            $table->foreign('customer_contact_person_id')->references('id')->on('customers_contact_person_details')->onDelete('cascade');
            $table->tinyInteger('project_status');
            $table->unsignedBigInteger('project_id');
            $table->foreign('project_id')->references('id')->on('projects')->onDelete('cascade');
            $table->longText('quotation_description')->nullable();
            $table->string('time_est_category');
            $table->string('est_time_period');
            $table->longText('scope_description');
            $table->double('project_cost', 10, 2);
            $table->double('discount', 10,2)->nullable();
            $table->double('total_cost', 10, 2);
            $table->string('payment_terms');
            $table->unsignedBigInteger('validity_period_id');
            $table->foreign('validity_period_id')->references('id')->on('validity_periods')->onDelete('cascade');
            $table->unsignedBigInteger('contact_person_id');
            $table->foreign('contact_person_id')->references('id')->on('company_contact_person_details')->onDelete('cascade');
            $table->char('status', 1)->default('Y');
            $table->tinyInteger('is_delete')->default(0);
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('quotations', function (Blueprint $table) {
            //
            $table->dropForeign(['customer_id']);
            $table->dropColumn(['customer_id']);
            $table->dropForeign(['project_id']);
            $table->dropColumn(['project_id']);
            $table->dropForeign(['validity_period_id']);
            $table->dropColumn(['validity_period_id']);
            $table->dropForeign(['contact_person_id']);
            $table->dropColumn(['contact_person_id']);
            $table->dropForeign(['customer_contact_person_id']);
            $table->dropColumn(['customer_contact_person_id']);
        });
        Schema::dropIfExists('quotations');
    }
};
