<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('invoices', function (Blueprint $table) {
            $table->id();
            $table->string('invoice_id');
            $table->date('invoice_date');
            $table->unsignedBigInteger('quotation_id');
            $table->foreign('quotation_id')->references('id')->on('quotations')->onDelete('cascade');
            $table->unsignedBigInteger('payment_term_id');
            $table->foreign('payment_term_id')->references('id')->on('payment_terms')->onDelete('cascade');
            $table->unsignedBigInteger('cust_contact_person_id');
            $table->foreign('cust_contact_person_id')->references('id')->on('customers_contact_person_details')->onDelete('cascade');
            $table->unsignedBigInteger('sales_person_id');
            $table->foreign('sales_person_id')->references('id')->on('company_contact_person_details')->onDelete('cascade');
            $table->string('po_number')->nullable();
            $table->string('fob_point')->nullable();
            $table->longText('remarks')->nullable();
            $table->longText('terms')->nullable();
            $table->unsignedBigInteger('project_id');
            $table->foreign('project_id')->references('id')->on('projects')->onDelete('cascade');
            $table->double('total_invoice_value', 10, 2);
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('invoices', function (Blueprint $table) {
            //
            $table->dropForeign(['quotation_id']);
            $table->dropColumn(['quotation_id']);
            $table->dropForeign(['payment_term_id']);
            $table->dropColumn(['payment_term_id']);
            $table->dropForeign(['cust_contact_person_id']);
            $table->dropColumn(['cust_contact_person_id']);
            $table->dropForeign(['sales_person_id']);
            $table->dropColumn(['sales_person_id']);
            $table->dropForeign(['project_id']);
            $table->dropColumn(['project_id']);
        });
        Schema::dropIfExists('invoices');
    }
};
