<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Invoice Print - {{ $invoice->incoice_id }}</title>
    <script type="text/javascript">
        window.onload = function() { window.print();  }
    </script>
    <style>
        @page {
            size: A4;
            margin: 0;
        }

        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 20px;
            color: #333;
        }

        .invoice-container {
            max-width: 800px;
            margin: auto;
            border: 1px solid #ddd;
            padding: 20px;
        }

        .header,
        .footer {
            text-align: center;
        }

        .header img {
            max-width: 150px;
        }

        .header h2 {
            font-size: 24px;
            color: #666;
        }

        .details,
        .items,
        .footer {
            width: 100%;
            margin-top: 20px;
        }

        .details td,
        .items td,
        .items th {
            padding: 8px;
            border: 1px solid #ddd;
            text-align: left;
        }

        .items {
            border-collapse: collapse;
        }

        .items th {
            background-color: #000;
            color: #fff;
        }

        .items td {
            text-align: right;
        }

        .items td:first-child {
            text-align: left;
        }

        .total td {
            font-weight: bold;
        }

        .note {
            font-size: 12px;
            color: #555;
            margin-top: 10px;
        }

    </style>
</head>
<body>

    <div class="invoice-container">
        <!-- Header -->
        <div class="header">
            <img src="{{ asset('public/back/img/logo.svg') }}" alt="tekGeeks Logo">
            <h2>{{ $companydetails->company_name }}</h2>
            <p>{{ $companydetails->address }}<br>
                Phone: {{ $companydetails->company_tel }}</p>
        </div>

        <!-- Invoice Details -->
        <table class="details">
            <tr>
                @if($invoice->customercontactpersons->title == 0)
                @php
                    $title = "Mr."
                @endphp
                @elseif($invoice->customercontactpersons->title == 1)
                @php
                    $title = "Mrs."
                @endphp
                @elseif($invoice->customercontactpersons->title == 2)
                @php
                    $title = "Miss."
                @endphp
                @elseif($invoice->customercontactpersons->title == 3)
                @php
                    $title = "Ms."
                @endphp
                @elseif($invoice->customercontactpersons->title == 4)
                @php
                    $title = "Dr."
                @endphp
                @elseif($invoice->customercontactpersons->title == 5)
                @php
                    $title = "Rev."
                @endphp
                @endif
                <td><strong>TO:</strong><br>{{ $title.''.$invoice->customercontactpersons->contact_person_name }}.<br>{{ $invoice->projects->project_name }}<br>{{ $invoice->quotations->customers->address_line_1 }} @if($invoice->quotations->customers->address_line_2)<br>{{ $invoice->quotations->customers->address_line_2 }}@endif @if($invoice->quotations->customers->address_line_3)<br>{{ $invoice->quotations->customers->address_line_3 }}@endif</td>
                <td><strong>INVOICE #:</strong> {{ $invoice->invoice_id }}<br><strong>DATE:</strong> {{ \Carbon\Carbon::parse($invoice->invoice_date)->format('M jS, Y') }}</td>
            </tr>
        </table>

        <!-- Sales Details -->
        <table class="details">
            <tr>
                <th>SALESPERSON</th>
                <th>P.O. NUMBER</th>
                <th>Remarks</th>
                <th>Quotation #</th>
                <th>F.O.B. POINT</th>
                <th>TERMS</th>
            </tr>
            <tr>
                <td>{{ $invoice->salespersons->contact_person_name }}</td>
                <td>{{ $invoice->po_number }}</td>
                <td>{{ $invoice->remarks }}</td>
                <td>{{ $invoice->quotations->quotation_id }}</td>
                <td>{{ $invoice->fob_point }}</td>
                <td>{{ $invoice->terms }}</td>
            </tr>
        </table>

        <!-- Item Table -->
        <table class="items">
            <tr>
                <th>#</th>
                <th>Description</th>
                <th>Unit Price</th>
                <th>Value (LKR)</th>
            </tr>
            <tr>
                <td>1</td>
                <td>
                    {{ $invoice->projects->project_name }}<br>
                    <small>{{ $invoice->paymentterms->payment_term }}</small>
                </td>
                <td>{{ $invoice->quotations->total_cost }}</td>
                <td>{{ $invoice->total_invoice_value }}</td>
            </tr>
            <tr class="total">
                <td colspan="3" style="text-align: right;">Sub Total</td>
                <td>{{ $invoice->total_invoice_value }}</td>
            </tr>
            <tr class="total">
                <td colspan="3" style="text-align: right;">Total</td>
                <td>{{ $invoice->total_invoice_value }}</td>
            </tr>
        </table>

        <!-- Footer Note -->
        <p>If you have any questions concerning this invoice, contact {{ $companydetails->company_tel }}</p>

        <!-- Payment Details -->
        <div class="footer">
            <p><strong>Payment Details:</strong><br>
                Account Name: {{ $bankdetails->account_name }}<br>
                Bank Name: {{ $bankdetails->bank_name }}<br>
                Branch Name: {{ $bankdetails->branch_name }}<br>
                Account Number: {{ $bankdetails->account_number }}<br>
                Bank Code: {{ $bankdetails->bank_code }}<br>
                Branch Code: {{ $bankdetails->branch_code }}<br>
                SWIFT Code: {{ $bankdetails->swift_code }}<br><br>
                Cheque should be drawn in favor of "TekGeeks (Pvt) Ltd"<br>
                Thank you for your business!</p>
        </div>

        <!-- Note -->
        <p class="note">Please note: This is a computer generated invoice & does not require manual signature.</p>
    </div>

</body>
</html>
