<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Quotation Print - {{ $quotationdetails->quotation_id }}</title>
    <script type="text/javascript">
        window.onload = function() { window.print();  }
    </script>
    <style>
        @page {
            size: A4;
            margin: 0;
        }
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
        }
        .container {
            width: 70%;
            margin: 0 auto;
            padding: 20px;
            /* border: 1px solid #000; */
        }
        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-bottom: 1px solid #000;
            padding-bottom: 10px;
        }
        .header img {
            width: 150px;
        }
        .header .quotation-title {
            text-align: right;
            font-weight: bold;
            font-size: 20px;
        }
        .header .quotation-date {
            text-align: right;
            font-size: 12px;
        }
        .client-info, .contact-info {
            margin: 20px 0;
        }
        .client-info .name {
            font-weight: bold;
        }
        .description-section, .terms-section, .contact-details {
            margin: 20px 0;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 10px;
        }
        table, th, td {
            border: 1px solid black;
        }
        th, td {
            padding: 10px;
            text-align: left;
        }
        .total-row {
            font-weight: bold;
        }
        .terms-section ul {
            list-style-type: none;
            padding-left: 0;
        }
        .terms-section ul li {
            margin-bottom: 5px;
        }
        .contact-details {
            font-size: 12px;
        }
        .highlight {
            background-color: #e0e0e0;
            padding: 2px 5px;
        }
    </style>
</head>
<body>

<div class="container">
    <div class="header">
        <img src="{{ asset('public/back/img/logo.svg') }}" alt="Logo">
        <div>
            <div class="quotation-title">QUOTATION</div>
            <div class="quotation-date"> {{ \Carbon\Carbon::parse($quotationdetails->quotation_date)->format('M jS, Y') }}<br>{{ $quotationdetails->quotation_id }}</div>
        </div>
    </div>

    <div class="client-info">
        <div class="name">{{ $quotationdetails->customercontactpersons->contact_person_name }},</div>
        <div>{{ $quotationdetails->customers->customer_name }}<br>{{ $quotationdetails->customers->address_line_1 }} @if($quotationdetails->customers->address_line_2)<br>{{ $quotationdetails->customers->address_line_2 }}@endif @if($quotationdetails->customers->address_line_3)<br>{{ $quotationdetails->customers->address_line_3 }}@endif</div>
    </div>

    <div class="description-section">
        <h4>{{ $quotationdetails->quotation_title }}</h4>
        <p>{{ $quotationdetails->quotation_description }}</p>
        <table>
            <tr>
                <th>Description</th>
                <th></th>
            </tr>
            <tr>
                <td>{!! $quotationdetails->scope_description !!}</td>
                <td></td>
            </tr>
            @if($quotationdetails->est_time_period)
            <tr>
                <td>Estimated Time</td>
                <td>{{ $quotationdetails->est_time_period }}</td>
            </tr>
            @endif
            <tr>
                <td><strong>Cost</strong></td>
                <td><strong>LKR {{ $quotationdetails->project_cost }}</strong></td>
            </tr>
            @if($quotationdetails->discount)
            <tr>
                <td><strong>Special Discount - {{ $quotationdetails->discount }}</strong></td>
                <td><strong>LKR {{ $quotationdetails->discount_amount }}</strong></td>
            </tr>
            @endif
            <tr>
                <td><strong>Total Cost</strong></td>
                <td><strong>LKR {{ $quotationdetails->total_cost }}</strong></td>
            </tr>
        </table>
    </div>

    <!-- Terms & Conditions Section -->
    <div class="terms">
        <h3>Terms & Conditions:</h3>
        <h4>Payment terms:</h4>
        <ul>
            @foreach ($paymentterms as $paymentterm)
            <li>{{ $paymentterm->paymentterms->payment_term }}</li>
            @endforeach
        </ul>
        <h4>Validity period:</h4>
        <p>{{ $quotationdetails->validityperiods->validity_period }}</p>
    </div>

    <!-- Contact Details Section -->
    <div class="contact-details">
        <h4>Contact details.</h4>
        <p><strong>{{ $quotationdetails->contactpersondetails->contact_person_name }}</strong><br>
            {{ $quotationdetails->contactpersondetails->contact_person_designation }}<br>
            Email: <a href="mailto:kasun@tekgeeks.net">{{ $quotationdetails->contactpersondetails->contact_person_email }}</a><br>
            Mobile: {{ $quotationdetails->contactpersondetails->contact_person_contact_no }}<br>
            <strong>{{ $companydetails->company_name }}</strong><br>
            {{ $companydetails->address }}<br>
            {{ $companydetails->company_tel }}<br>
            <a href="{{ $companydetails->website_url }}" target="_blank">{{ $companydetails->website_url }}</a>
        </p>
    </div>
</div>

</body>
</html>
