<?php

use App\Http\Controllers\Adminpanel\CustomersController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\Adminpanel\UserController;
use App\Http\Controllers\Adminpanel\ProfileController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\Auth\NewPasswordController;
use App\Http\Controllers\Auth\VerifyEmailController;
use App\Http\Controllers\Auth\RegisteredUserController;
use App\Http\Controllers\Auth\PasswordResetLinkController;
use App\Http\Controllers\Auth\ConfirmablePasswordController;
use App\Http\Controllers\Auth\AuthenticatedSessionController;
use App\Http\Controllers\Auth\EmailVerificationPromptController;
use App\Http\Controllers\Auth\EmailVerificationNotificationController;
use App\Http\Controllers\Adminpanel\DashboardController;
use App\Http\Controllers\Adminpanel\InvoiceController;
use App\Http\Controllers\Adminpanel\LogActivityController;
use App\Http\Controllers\Adminpanel\MaintenanceManagementController;
use App\Http\Controllers\Adminpanel\Masterdata\CompanyDetailController;
use App\Http\Controllers\Adminpanel\Masterdata\EmailSettingsController;
use App\Http\Controllers\Adminpanel\Masterdata\MaintenanceTypeController;
use App\Http\Controllers\Adminpanel\Masterdata\PaymentTermController;
use App\Http\Controllers\Adminpanel\Masterdata\ValidityPeriodController;
use App\Http\Controllers\Adminpanel\ProjectController;
use App\Http\Controllers\Adminpanel\QuotationsController;
use App\Http\Controllers\Adminpanel\SendEmailsController;

Route::get('/register', [RegisteredUserController::class, 'create'])
    ->middleware('guest')
    ->name('register');

Route::post('/register', [RegisteredUserController::class, 'store'])
    ->middleware('guest');

Route::get('/login', [AuthenticatedSessionController::class, 'create'])
    ->middleware('guest')
    ->name('login');

Route::post('/login', [AuthenticatedSessionController::class, 'store'])
    ->middleware('guest');

Route::get('/forgot-password', [PasswordResetLinkController::class, 'create'])
    ->middleware('guest')
    ->name('password.request');

Route::post('/forgot-password', [PasswordResetLinkController::class, 'store'])
    ->middleware('guest')
    ->name('password.email');

Route::get('/reset-password/{token}', [NewPasswordController::class, 'create'])
    ->middleware('guest')
    ->name('password.reset');

Route::post('/reset-password', [NewPasswordController::class, 'store'])
    ->middleware('guest')
    ->name('password.update');

Route::get('/verify-email', [EmailVerificationPromptController::class, '__invoke'])
    ->middleware('auth')
    ->name('verification.notice');

Route::get('/verify-email/{id}/{hash}', [VerifyEmailController::class, '__invoke'])
    ->middleware(['auth', 'signed', 'throttle:6,1'])
    ->name('verification.verify');

Route::post('/email/verification-notification', [EmailVerificationNotificationController::class, 'store'])
    ->middleware(['auth', 'throttle:6,1'])
    ->name('verification.send');

Route::get('/confirm-password', [ConfirmablePasswordController::class, 'show'])
    ->middleware('auth')
    ->name('password.confirm');

Route::post('/confirm-password', [ConfirmablePasswordController::class, 'store'])
    ->middleware('auth');

Route::get('/logout', [AuthenticatedSessionController::class, 'destroy'])
    ->middleware('auth')
    ->name('logout');

Route::group(['middleware' => ['auth']], function () {
    Route::get('roles-list', [RoleController::class, 'index'])->name('roles-list');
    Route::get('roles-create', [RoleController::class, 'create'])->name('roles-create');
    Route::post('roles-save', [RoleController::class, 'store'])->name('roles-save');
    Route::get('roles-edit/{id}', [RoleController::class, 'edit'])->name('roles-edit');
    Route::put('update-role', [RoleController::class, 'update'])->name('update-role');
    Route::post('new-users', [UserController::class, 'store'])->name('new-users');
    Route::get('users', [UserController::class, 'index'])->name('users');
    Route::get('/edit-users/{id}', [UserController::class, 'edit'])->name('edit-users');
    Route::get('users-list',[UserController::class,'list'])->name('users-list');
    Route::put('save-user', [UserController::class, 'update'])->name('save-user');
    Route::get('changestatus-user/{id}', [UserController::class, 'activation'])->name('changestatus-user');
    Route::get('blockuser/{id}', [UserController::class, 'block'])->name('blockuser');
    Route::post('checkEmailAvailability', [UserController::class, 'checkEmailAvailability'])->name('checkEmailAvailability');
    Route::resource('adminpanel/products', ProductController::class);


    // Route::resource('roles', RoleController::class);
    // Route::put('update-role', [RoleController::class, 'update'])->name('update-role');
    // Route::resource('users', UserController::class);
    // Route::get('users-list',[UserController::class,'list'])->name('users-list');
    // Route::put('save-user', [UserController::class, 'update'])->name('save-user');
    // Route::get('changestatus-user/{id}', [UserController::class, 'activation'])->name('changestatus-user');
    // Route::get('blockuser/{id}', [UserController::class, 'block'])->name('blockuser');
    // Route::post('checkEmailAvailability', [UserController::class, 'checkEmailAvailability'])->name('checkEmailAvailability');
    // Route::resource('products', ProductController::class);


    Route::get('log-activity-list', [LogActivityController::class, 'list'])->name('log-activity-list');

    Route::get('dashboard', [DashboardController::class, 'index'])->name('dashboard');

    Route::view('profile', 'profile')->name('profile');
    Route::put('profile', [ProfileController::class, 'update'])->name('profile.update');

    Route::get('create-payment-terms', [PaymentTermController::class, 'index'])->name('create-payment-terms');
    Route::post('save-payment-terms', [PaymentTermController::class, 'store'])->name('save-payment-terms');
    Route::get('payment-terms-list', [PaymentTermController::class, 'list'])->name('payment-terms-list');
    Route::get('/edit-payment-terms/{id}', [PaymentTermController::class, 'edit'])->name('edit-payment-terms');
    Route::put('update-payment-terms', [PaymentTermController::class, 'update'])->name('update-payment-terms');
    Route::get('change-status-payment-terms/{id}', [PaymentTermController::class, 'activation'])->name('change-status-payment-terms');
    Route::get('delete-payment-terms/{id}', [PaymentTermController::class, 'delete'])->name('delete-payment-terms');

    Route::get('create-validity-periods', [ValidityPeriodController::class, 'index'])->name('create-validity-periods');
    Route::post('save-validity-periods', [ValidityPeriodController::class, 'store'])->name('save-validity-periods');
    Route::get('validity-periods-list', [ValidityPeriodController::class, 'list'])->name('validity-periods-list');
    Route::get('/edit-validity-periods/{id}', [ValidityPeriodController::class, 'edit'])->name('edit-validity-periods');
    Route::put('update-validity-periods', [ValidityPeriodController::class, 'update'])->name('update-validity-periods');
    Route::get('change-status-validity-periods/{id}', [ValidityPeriodController::class, 'activation'])->name('change-status-validity-periods');
    Route::get('delete-validity-periods/{id}', [ValidityPeriodController::class, 'delete'])->name('delete-validity-periods');

    Route::get('create-maintenance-type', [MaintenanceTypeController::class, 'index'])->name('create-maintenance-type');
    Route::post('save-maintenance-type', [MaintenanceTypeController::class, 'store'])->name('save-maintenance-type');
    Route::get('maintenance-type-list', [MaintenanceTypeController::class, 'list'])->name('maintenance-type-list');
    Route::get('/edit-maintenance-type/{id}', [MaintenanceTypeController::class, 'edit'])->name('edit-maintenance-type');
    Route::put('update-maintenance-type', [MaintenanceTypeController::class, 'update'])->name('update-maintenance-type');
    Route::get('change-status-maintenance-type/{id}', [MaintenanceTypeController::class, 'activation'])->name('change-status-maintenance-type');
    Route::get('delete-maintenance-type/{id}', [MaintenanceTypeController::class, 'delete'])->name('delete-maintenance-type');

    Route::get('create-email-settings', [EmailSettingsController::class, 'index'])->name('create-email-settings');
    Route::post('save-email-settings', [EmailSettingsController::class, 'store'])->name('save-email-settings');
    Route::get('email-settings-list', [EmailSettingsController::class, 'list'])->name('email-settings-list');
    Route::get('/edit-email-settings/{id}', [EmailSettingsController::class, 'edit'])->name('edit-email-settings');
    Route::put('update-email-settings', [EmailSettingsController::class, 'update'])->name('update-email-settings');
    Route::get('change-status-email-settings/{id}', [EmailSettingsController::class, 'activation'])->name('change-status-email-settings');
    Route::get('delete-email-settings/{id}', [EmailSettingsController::class, 'delete'])->name('delete-email-settings');
    Route::post('check-existting-types', [EmailSettingsController::class, 'checkExistingTypes'])->name('check-existting-types');

    Route::get('company-details', [CompanyDetailController::class, 'list'])->name('company-details');
    Route::get('/edit-company-details/{id}', [CompanyDetailController::class, 'edit'])->name('edit-company-details');
    Route::put('update-company-details', [CompanyDetailController::class, 'update'])->name('update-company-details');
    Route::get('edit-company-details/contact-person-record-delete/{id}', [CompanyDetailController::class, 'delete'])->name('contact-person-record-delete');

    Route::get('create-customers', [CustomersController::class, 'index'])->name('create-customers');
    Route::post('save-customers', [CustomersController::class, 'store'])->name('save-customers');
    Route::get('customers-list', [CustomersController::class, 'list'])->name('customers-list');
    Route::get('/edit-customers/{id}', [CustomersController::class, 'edit'])->name('edit-customers');
    Route::put('update-customers', [CustomersController::class, 'update'])->name('update-customers');
    Route::get('change-status-customers/{id}', [CustomersController::class, 'activation'])->name('change-status-customers');
    Route::get('delete-customers/{id}', [CustomersController::class, 'delete'])->name('delete-customers');
    Route::get('edit-customers/customer-contact-person-record-delete/{id}', [CustomersController::class, 'deleteContactPerson'])->name('customer-contact-person-record-delete');

    Route::get('create-quotation', [QuotationsController::class, 'index'])->name('create-quotation');
    Route::post('save-quotation', [QuotationsController::class, 'store'])->name('save-quotation');
    Route::get('quotation-list', [QuotationsController::class, 'list'])->name('quotation-list');
    Route::get('/edit-quotation/{id}', [QuotationsController::class, 'edit'])->name('edit-quotation');
    Route::put('update-quotation', [QuotationsController::class, 'update'])->name('update-quotation');
    Route::get('quotation-cancel/{id}', [QuotationsController::class, 'cancel'])->name('quotation-cancel');
    Route::get('/print-quotation/{id}', [QuotationsController::class, 'print'])->name('print-quotation');
    Route::get('/generate-invoice/{id}', [QuotationsController::class, 'generateInvoice'])->name('generate-invoice');
    Route::get('cancel-quotation-list', [QuotationsController::class, 'cancelList'])->name('cancel-quotation-list');
    Route::get('/view-quotation/{id}', [QuotationsController::class, 'view'])->name('view-quotation');

    Route::get('create-invoice', [InvoiceController::class, 'index'])->name('create-invoice');
    Route::get('invoice-list', [InvoiceController::class, 'list'])->name('invoice-list');
    Route::post('save-invoice', [InvoiceController::class, 'store'])->name('save-invoice');
    Route::get('/edit-invoice/{id}', [InvoiceController::class, 'edit'])->name('edit-invoice');
    Route::put('update-invoice', [InvoiceController::class, 'update'])->name('update-invoice');
    Route::get('/print-invoice/{id}', [InvoiceController::class, 'print'])->name('print-invoice');
    Route::post('get-project-details', [InvoiceController::class, 'getProjectDetails'])->name('get-project-details');
    Route::post('get-contact-persons', [InvoiceController::class, 'getCustomerContactDetails'])->name('get-contact-persons');

    Route::get('project-list', [ProjectController::class, 'list'])->name('project-list');
    Route::get('create-project', [ProjectController::class, 'index'])->name('create-project');
    Route::post('save-project', [ProjectController::class, 'store'])->name('save-project');
    Route::get('project-list', [ProjectController::class, 'list'])->name('project-list');
    Route::get('/edit-project/{id}', [ProjectController::class, 'edit'])->name('edit-project');
    Route::put('update-project', [ProjectController::class, 'update'])->name('update-project');
    Route::get('change-status-project/{id}', [ProjectController::class, 'activation'])->name('change-status-project');
    Route::get('project-cancel/{id}', [ProjectController::class, 'cancel'])->name('project-cancel');
    Route::get('cancel-project-list', [ProjectController::class, 'cancelList'])->name('cancel-project-list');

    Route::get('create-new-maintenance', [MaintenanceManagementController::class, 'index'])->name('create-new-maintenance');
    Route::post('save-maintenance', [MaintenanceManagementController::class, 'store'])->name('save-maintenance');
    Route::get('maintenance-list', [MaintenanceManagementController::class, 'list'])->name('maintenance-list');
    Route::get('/edit-maintenance/{id}', [MaintenanceManagementController::class, 'edit'])->name('edit-maintenance');
    Route::put('update-maintenance', [MaintenanceManagementController::class, 'update'])->name('update-maintenance');
    Route::get('cancel-maintenance/{id}', [MaintenanceManagementController::class, 'cancel'])->name('cancel-maintenance');
    Route::get('/print-maintenance/{id}', [MaintenanceManagementController::class, 'print'])->name('print-maintenance');
    Route::get('/generate-invoice/{id}', [MaintenanceManagementController::class, 'generateInvoice'])->name('generate-invoice');
    Route::get('cancel-maintenance-list', [MaintenanceManagementController::class, 'cancelList'])->name('cancel-maintenance-list');
    Route::get('/view-maintenance/{id}', [MaintenanceManagementController::class, 'view'])->name('view-maintenance');
    Route::get('/update-maintenance-status/{id}', [MaintenanceManagementController::class, 'updateStatus'])->name('update-maintenance-status');
    Route::put('save-maintenance-status', [MaintenanceManagementController::class, 'saveUpdatedStatus'])->name('save-maintenance-status');
    Route::get('renewal-completed-maintenance-list', [MaintenanceManagementController::class, 'renewalCompletedList'])->name('renewal-completed-maintenance-list');

    Route::post('get-projects', [QuotationsController::class, 'getProjects'])->name('get-projects');
    Route::post('get-customer-contact-persons', [QuotationsController::class, 'getCustomerContactPersons'])->name('get-customer-contact-persons');
    Route::post('get-payment-terms', [QuotationsController::class, 'getPaymentTerms'])->name('get-payment-terms');
    Route::post('get-payment-term-percentage', [QuotationsController::class, 'getPaymentTermPercentage'])->name('get-payment-term-percentage');

    Route::get('send-maintenance-reminder-email', [SendEmailsController::class, 'invoice_reminder_email'])->name('send-maintenance-reminder-email');


});
