<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Quotation Print - <?php echo e($quotationdetails->quotation_id); ?></title>
    <script type="text/javascript">
        window.onload = function() { window.print();  }
    </script>
    <style>
        @page {
            size: A4;
            margin: 0;
        }
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
        }
        .container {
            width: 70%;
            margin: 0 auto;
            padding: 20px;
            /* border: 1px solid #000; */
        }
        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-bottom: 1px solid #000;
            padding-bottom: 10px;
        }
        .header img {
            width: 150px;
        }
        .header .quotation-title {
            text-align: right;
            font-weight: bold;
            font-size: 20px;
        }
        .header .quotation-date {
            text-align: right;
            font-size: 12px;
        }
        .client-info, .contact-info {
            margin: 20px 0;
        }
        .client-info .name {
            font-weight: bold;
        }
        .description-section, .terms-section, .contact-details {
            margin: 20px 0;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 10px;
        }
        table, th, td {
            border: 1px solid black;
        }
        th, td {
            padding: 10px;
            text-align: left;
        }
        .total-row {
            font-weight: bold;
        }
        .terms-section ul {
            list-style-type: none;
            padding-left: 0;
        }
        .terms-section ul li {
            margin-bottom: 5px;
        }
        .contact-details {
            font-size: 12px;
        }
        .highlight {
            background-color: #e0e0e0;
            padding: 2px 5px;
        }
    </style>
</head>
<body>

<div class="container">
    <div class="header">
        <img src="<?php echo e(asset('public/back/img/logo.svg')); ?>" alt="Logo">
        <div>
            <div class="quotation-title">QUOTATION</div>
            <div class="quotation-date"> <?php echo e(\Carbon\Carbon::parse($quotationdetails->quotation_date)->format('M jS, Y')); ?><br><?php echo e($quotationdetails->quotation_id); ?></div>
        </div>
    </div>

    <div class="client-info">
        <div class="name"><?php echo e($quotationdetails->customercontactpersons->contact_person_name); ?>,</div>
        <div><?php echo e($quotationdetails->customers->customer_name); ?><br><?php echo e($quotationdetails->customers->address_line_1); ?> <?php if($quotationdetails->customers->address_line_2): ?><br><?php echo e($quotationdetails->customers->address_line_2); ?><?php endif; ?> <?php if($quotationdetails->customers->address_line_3): ?><br><?php echo e($quotationdetails->customers->address_line_3); ?><?php endif; ?></div>
    </div>

    <div class="description-section">
        <h4><?php echo e($quotationdetails->quotation_title); ?></h4>
        <p><?php echo e($quotationdetails->quotation_description); ?></p>
        <table>
            <tr>
                <th>Description</th>
                <th></th>
            </tr>
            <tr>
                <td><?php echo $quotationdetails->scope_description; ?></td>
                <td></td>
            </tr>
            <?php if($quotationdetails->est_time_period): ?>
            <tr>
                <td>Estimated Time</td>
                <td><?php echo e($quotationdetails->est_time_period); ?></td>
            </tr>
            <?php endif; ?>
            <tr>
                <td><strong>Cost</strong></td>
                <td><strong>LKR <?php echo e($quotationdetails->project_cost); ?></strong></td>
            </tr>
            <?php if($quotationdetails->discount): ?>
            <tr>
                <td><strong>Special Discount - <?php echo e($quotationdetails->discount); ?></strong></td>
                <td><strong>LKR <?php echo e($quotationdetails->discount_amount); ?></strong></td>
            </tr>
            <?php endif; ?>
            <tr>
                <td><strong>Total Cost</strong></td>
                <td><strong>LKR <?php echo e($quotationdetails->total_cost); ?></strong></td>
            </tr>
        </table>
    </div>

    <!-- Terms & Conditions Section -->
    <div class="terms">
        <h3>Terms & Conditions:</h3>
        <h4>Payment terms:</h4>
        <ul>
            <?php $__currentLoopData = $paymentterms; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $paymentterm): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <li><?php echo e($paymentterm->paymentterms->payment_term); ?></li>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
        </ul>
        <h4>Validity period:</h4>
        <p><?php echo e($quotationdetails->validityperiods->validity_period); ?></p>
    </div>

    <!-- Contact Details Section -->
    <div class="contact-details">
        <h4>Contact details.</h4>
        <p><strong><?php echo e($quotationdetails->contactpersondetails->contact_person_name); ?></strong><br>
            <?php echo e($quotationdetails->contactpersondetails->contact_person_designation); ?><br>
            Email: <a href="mailto:kasun@tekgeeks.net"><?php echo e($quotationdetails->contactpersondetails->contact_person_email); ?></a><br>
            Mobile: <?php echo e($quotationdetails->contactpersondetails->contact_person_contact_no); ?><br>
            <strong><?php echo e($companydetails->company_name); ?></strong><br>
            <?php echo e($companydetails->address); ?><br>
            <?php echo e($companydetails->company_tel); ?><br>
            <a href="<?php echo e($companydetails->website_url); ?>" target="_blank"><?php echo e($companydetails->website_url); ?></a>
        </p>
    </div>
</div>

</body>
</html>
<?php /**PATH /home/stagingtekgeeks/public_html/quotation_management/resources/views/adminpanel/quotations/print_quotation.blade.php ENDPATH**/ ?>